@@ -87,7 +87,7 @@ static ipkg_cmd_t cmds[] = {
      {"status", 0, ipkg_status_cmd},
      {"install_pending", 0, ipkg_install_pending_cmd},
      {"install", 1, ipkg_install_cmd},
-     {"remove", 0, ipkg_remove_cmd},
+     {"remove", 1, ipkg_remove_cmd},
      {"purge", 1, ipkg_purge_cmd},
      {"configure", 0, ipkg_configure_cmd},
      {"files", 1, ipkg_files_cmd},
@@ -537,9 +537,9 @@ static int ipkg_list_cmd(ipkg_conf_t *conf, int argc, char **argv)
 #ifndef IPKG_LIB
 	  printf("%s - %s\n", pkg->name, desc_short);
 #else
-	  if (ipkg_cb_list) ipkg_cb_list(pkg->name,desc_short, 
-		                             pkg_version_str_alloc(pkg), 
-	                                 pkg->state_status, 
+	  if (ipkg_cb_list) ipkg_cb_list(pkg->name,desc_short,
+		                             pkg_version_str_alloc(pkg),
+	                                 pkg->state_status,
 	                                 p_userdata);
 #endif
      }
@@ -551,14 +551,15 @@ static int ipkg_list_cmd(ipkg_conf_t *conf, int argc, char **argv)
 
 static int ipkg_info_status_cmd(ipkg_conf_t *conf, int argc, char **argv, int installed_only)
 {
-     int i, j, err;
+     int i, err;
      pkg_vec_t *available;
      pkg_t *pkg;
      char *pkg_name = NULL;
      char **pkg_fields = NULL;
-     int n_fields = 0; 
+     int n_fields = 0;
      regex_t re;
-    
+     char *buff ; // = (char *)malloc(1);
+
      if (argc > 0) {
 	  pkg_name = argv[0];
 	  err = ipkg_regcomp(&re, pkg_name);
@@ -581,25 +582,45 @@ static int ipkg_info_status_cmd(ipkg_conf_t *conf, int argc, char **argv, int in
 	  if (pkg_name && xregexec(&re, pkg->name, 0, 0, 0)) {
 	       continue;
 	  }
+#ifndef IPKG_LIB
 	  if (n_fields) {
 	       for (j = 0; j < n_fields; j++)
 		    pkg_print_field(pkg, stdout, pkg_fields[j]);
 	  } else {
 	       pkg_print_info(pkg, stdout);
 	  }
+#else
+
+	  buff = pkg_formatted_info(pkg);
+          if ( buff ) {
+	       if (ipkg_cb_status) ipkg_cb_status(pkg->name,
+						  pkg->state_status,
+						  buff,
+						  p_userdata);
+/* 
+   We should not forget that actually the pointer is allocated. 
+   We need to free it :)  ( Thanks florian for seeing the error )
+*/
+               free(buff);
+          }
+#endif
 	  if (conf->verbosity > 1) {
 	       conffile_list_elt_t *iter;
 	       for (iter = pkg->conffiles.head; iter; iter = iter->next) {
 		    conffile_t *cf = iter->data;
 		    int modified = conffile_has_been_modified(conf, cf);
-		    ipkg_message(conf, IPKG_NOTICE, "conffile=%s md5sum=%s modified=%d\n", 
+		    ipkg_message(conf, IPKG_NOTICE, "conffile=%s md5sum=%s modified=%d\n",
 				 cf->name, cf->value, modified);
 	       }
 	  }
      }
+#ifndef IPKG_LIB
+     if (buff)
+	  free(buff);
+#endif
      pkg_vec_free(available);
      if (pkg_name)
-       xregfree(&re);
+	  xregfree(&re);
      return 0;
 }
 
@@ -615,22 +636,24 @@ static int ipkg_status_cmd(ipkg_conf_t *conf, int argc, char **argv)
 
 static int ipkg_configure_cmd(ipkg_conf_t *conf, int argc, char **argv)
 {
-     char *pkg_name = NULL;
-     regex_t re;
      int err;
      
      if (argc > 0) {
+          regex_t re;
+	  char *pkg_name = NULL;
+
 	  pkg_name = argv[0];
 	  err = ipkg_regcomp(&re, pkg_name);
 	  if (err) {
 	       return err;
 	  }
+
+	  err = ipkg_configure_packages (conf, &re);
+     
+	  xregfree(&re);
+     } else {
+	  err = ipkg_configure_packages (conf, NULL);
      }
-     
-     err = ipkg_configure_packages (conf, &re);
-     
-     if (pkg_name)
-       xregfree(&re);
 
      return err;
 }
@@ -798,7 +821,15 @@ static int ipkg_flag_cmd(ipkg_conf_t *conf, int argc, char **argv)
 			    "Package %s is not installed.\n", argv[i]);
 	       continue;
 	  }
-	  pkg->state_flag = pkg_state_flag_from_str(flags);
+          if (( strcmp(flags,"hold")==0)||( strcmp(flags,"noprune")==0)||
+              ( strcmp(flags,"user")==0)||( strcmp(flags,"ok")==0)) {
+	      pkg->state_flag = pkg_state_flag_from_str(flags);
+          }
+/* pb_ asked this feature 03292004 */
+/* Actually I will use only this two, but this is an open for various status */
+          if (( strcmp(flags,"installed")==0)||( strcmp(flags,"unpacked")==0)){
+	      pkg->state_status = pkg_state_status_from_str(flags);
+          }
 	  ipkg_state_changed++;
 	  ipkg_message(conf, IPKG_NOTICE,
 		       "Setting flags for package %s to %s\n",
@@ -815,6 +846,14 @@ static int ipkg_files_cmd(ipkg_conf_t *conf, int argc, char **argv)
      str_list_t *installed_files;
      str_list_elt_t *iter;
      char *pkg_version;
+     size_t buff_len = 8192;
+     char *buff ;
+
+     buff = (char *)malloc(buff_len);
+     if ( buff == NULL ) {
+        fprintf( stderr,"%s: Unable to allocate memory \n",__FUNCTION__);
+        return ENOMEM;
+     }
  
      if (argc < 1) {
 	  return EINVAL;
@@ -830,12 +869,31 @@ static int ipkg_files_cmd(ipkg_conf_t *conf, int argc, char **argv)
 
      installed_files = pkg_get_installed_files(pkg);
      pkg_version = pkg_version_str_alloc(pkg);
+
+#ifndef IPKG_LIB
      printf("Package %s (%s) is installed on %s and has the following files:\n",
 	    pkg->name, pkg_version, pkg->dest->name);
-     free(pkg_version);
      for (iter = installed_files->head; iter; iter = iter->next) {
 	  puts(iter->data);
      }
+#else
+     if (buff) {
+	  snprintf(buff, buff_len, "Package %s (%s) is installed on %s and has the following files:\n",
+		   pkg->name, pkg_version, pkg->dest->name);
+	  for (iter = installed_files->head; iter; iter = iter->next) {
+	       strncat(buff, iter->data, buff_len);
+	       strncat(buff, "\n", buff_len);
+	  } 
+	  if (ipkg_cb_list) ipkg_cb_list(pkg->name,
+					 buff,
+					 pkg_version_str_alloc(pkg),
+					 pkg->state_status,
+					 p_userdata);
+	  free(buff);
+     }
+#endif
+
+     free(pkg_version);
      pkg_free_installed_files(pkg);
 
      return 0;
