@@ -30,7 +30,7 @@
 static int ipkg_conf_parse_file(ipkg_conf_t *conf, const char *filename,
 				pkg_src_list_t *pkg_src_list,
 				nv_pair_list_t *tmp_dest_nv_pair_list);
-static void ipkg_init_options_array(const ipkg_conf_t *conf, ipkg_option_t **options);
+static int ipkg_init_options_array(const ipkg_conf_t *conf, ipkg_option_t **options);
 static int ipkg_conf_set_option(const ipkg_option_t *options,
 				const char *name, const char *value);
 static int ipkg_conf_set_default_dest(ipkg_conf_t *conf,
@@ -40,7 +40,7 @@ static int set_and_load_pkg_src_list(ipkg_conf_t *conf,
 static int set_and_load_pkg_dest_list(ipkg_conf_t *conf,
 				      nv_pair_list_t *nv_pair_list);
 
-void ipkg_init_options_array(const ipkg_conf_t *conf, ipkg_option_t **options)
+int ipkg_init_options_array(const ipkg_conf_t *conf, ipkg_option_t **options)
 {
      ipkg_option_t tmp[] = {
 	  { "force_defaults", IPKG_OPT_TYPE_BOOL, &conf->force_defaults },
@@ -68,7 +68,13 @@ void ipkg_init_options_array(const ipkg_conf_t *conf, ipkg_option_t **options)
      };
 
      *options = (ipkg_option_t *)malloc(sizeof(tmp));
+     if ( options == NULL ){
+        fprintf(stderr,"%s: Unable to allocate memory\n",__FUNCTION__);
+        return -1;
+     }
+
      memcpy(*options, tmp, sizeof(tmp));
+     return 0;
 };
 
 static void ipkg_conf_override_string(char **conf_str, char *arg_str) 
@@ -155,8 +161,12 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
 	  struct stat stat_buf;
 	  err = stat(args->conf_file, &stat_buf);
 	  if (err == 0)
-	       ipkg_conf_parse_file(conf, args->conf_file,
-				    &conf->pkg_src_list, &tmp_dest_nv_pair_list);
+	       if (ipkg_conf_parse_file(conf, args->conf_file,
+				    &conf->pkg_src_list, &tmp_dest_nv_pair_list)<0) {
+                   /* Memory leakage from ipkg_conf_parse-file */
+                   return -1;
+               }
+                   
      }
 
      if (args->offline_root) 
@@ -167,8 +177,11 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
 	  int i;
 	  for (i = 0; i < globbuf.gl_pathc; i++) {
 	       if (globbuf.gl_pathv[i]) 
-		    ipkg_conf_parse_file(conf, globbuf.gl_pathv[i], 
-					 &conf->pkg_src_list, &tmp_dest_nv_pair_list);
+		    if ( ipkg_conf_parse_file(conf, globbuf.gl_pathv[i], 
+					 &conf->pkg_src_list, &tmp_dest_nv_pair_list)<0 ){
+                        /* Memory leakage from ipkg_conf_parse-file */
+                        return -1;
+	            }
 	  }
      }
      globfree(&globbuf);
@@ -227,9 +240,9 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
      if (args->multiple_providers) {
 	  conf->multiple_providers = 1;
      }
-     if (args->verbosity) {
+     if (args->verbosity != conf->verbosity) {
 	  conf->verbosity = args->verbosity;
-     }
+     } 
 
      ipkg_conf_override_string(&conf->offline_root, 
 			       args->offline_root);
@@ -238,21 +251,25 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
      ipkg_conf_override_string(&conf->offline_root_post_script_cmd, 
 			       args->offline_root_post_script_cmd);
 
-     /* need to run load the source list before dest list -Jamey */
-     set_and_load_pkg_src_list(conf, &conf->pkg_src_list);
-
-     /* Now that we have resolved conf->offline_root, we can commit to
-	the directory names for the dests and load in all the package
-	lists. */
-     set_and_load_pkg_dest_list(conf, &tmp_dest_nv_pair_list);
-
-     if (args->dest) {
-	  err = ipkg_conf_set_default_dest(conf, args->dest);
-	  if (err) {
-	       return err;
-	  }
+/* Pigi: added a flag to disable the checking of structures if the command does not need to 
+         read anything from there.
+*/
+     if ( !(args->nocheckfordirorfile)){
+        /* need to run load the source list before dest list -Jamey */
+        set_and_load_pkg_src_list(conf, &conf->pkg_src_list);
+   
+        /* Now that we have resolved conf->offline_root, we can commit to
+	   the directory names for the dests and load in all the package
+	   lists. */
+        set_and_load_pkg_dest_list(conf, &tmp_dest_nv_pair_list);
+   
+        if (args->dest) {
+	     err = ipkg_conf_set_default_dest(conf, args->dest);
+	     if (err) {
+	          return err;
+	     }
+        }
      }
-
      nv_pair_list_deinit(&tmp_dest_nv_pair_list);
 
      return 0;
@@ -412,7 +429,8 @@ static int ipkg_conf_parse_file(ipkg_conf_t *conf, const char *filename,
 #define regmatch_size 12
      regmatch_t regmatch[regmatch_size];
 
-     ipkg_init_options_array(conf, &options);
+     if (ipkg_init_options_array(conf, &options)<0)
+        return ENOMEM;
 
      if (file == NULL) {
 	  fprintf(stderr, "%s: failed to open %s: %s\n",
